<p align="center">
    <img src="https://ucloud-sdk.dl.ufileos.com/logos%2Flogo-mini.png" />
</p>

<h1 align="center">UCloud SDK Python 3</h1>

<p align="center">
<a href="https://pypi.python.org/pypi/ucloud-sdk-python3/"><img src="https://img.shields.io/pypi/v/ucloud-sdk-python3.svg" alt="Latest Stable Version"></a>
<a href="https://travis-ci.org/ucloud/ucloud-sdk-python3"><img src="https://travis-ci.org/ucloud/ucloud-sdk-python3.svg?branch=master" alt="Travis CI Status"></a>
<a href="https://codecov.io/github/ucloud/ucloud-sdk-python3?branch=master"><img src="https://codecov.io/github/ucloud/ucloud-sdk-python3/coverage.svg?branch=master" alt="Codecov Status"></a>
<a href="https://ucloud.github.io/ucloud-sdk-python3/"><img src="https://img.shields.io/badge/docs-passing-brightgreen.svg" alt="Doc Status"></a>
</p>

UCloud SDK is a Python client library for accessing the UCloud API.

This client can run on Linux, macOS and Windows.

- Website: https://www.ucloud.cn/
- Free software: Apache 2.0 license
- [Documentation](https://docs.ucloud.cn/opensdk-python/)
